Procedural macros for the prehook library.
This crate provides the #[hook] and #[interpose] attribute macros,
which are the primary ways to define interceptions in the prehook ecosystem.
Procedural macros for the prehook library.
This crate provides the #[hook] and #[interpose] attribute macros,
which are the primary ways to define interceptions in the prehook ecosystem.